use "$intermediate/adhd_cells_countygrade", clear

*set up event study variables
gen exp = monthnum-14 if cohort==2

recode exp (.=-1)

char exp[omit] -1

xi i.exp, pref(_T)



*Overall Event Study
capture program drop estudy
**************
program define estudy
**************  
syntax , title(string) depvar(varlist) absorbvars(string) [weight(string)] [controls(varlist)] [controls2(varlist)]

capture mat drop _all
mat month = -7\-6\-5\-4\-3\-2\0\1\2\3\4\5\6\7\8\9\10\11\.\.\.\.\.\.\-7\-6\-5\-4\-3\-2\0\1\2\3\4\5\6\7\8\9\10\11\.\.\.\.\.\.\.\.
mat coln month = month

ppmlhdfe `depvar' _Texp* `controls2' `weight', absorb(`absorbvars') cluster(countycohort) eform

mat event1 = r(table)'

ppmlhdfe `depvar' _Texp* `controls' `controls2' `weight', absorb(`absorbvars') cluster(countycohort) eform

mat event2 = r(table)'

mat event = event1 \ event2

mat event = event , month  

capture drop _all
svmat event, names(col) 

replace b = b-1
replace ll = ll-1
replace ul = ul-1
gen ll_transformed = ll
gen ul_transformed = ul
replace ll = b-crit*se
replace ul = b+crit*se


drop if month == .

gen controls_included = 0 in 1/18
replace controls_included =1 in 19/36

set obs 38

replace b = 0 if month == .
replace month = -1 if month == .
replace controls_included = 0 in 37
replace controls_included = 1 in 38

label define eventmonth -7 "Aug" -6 "Sept" -5 "Oct" -4 "Nov" -3 "Dec" -2 "Jan" -1 "Feb" 0 "Mar" 1 "Apr" 2 "May" 3 "Jun" 4 "Jul" 5 "Aug" 6 "Sep" 7 "Oct" 8 "Nov" 9 "Dec" 10 "Jan" 11 "Feb", replace
lab val month eventmonth 

gen eventmonth = month-.1 if controls_included==0
replace eventmonth = month+.1 if controls_included==1

lab val eventmonth eventmonth

sort controls_included eventmonth

tw (rspike ll ul eventmonth if controls_included==0, lcolor(gs12)) (scatter b eventmonth if controls_included == 0, mcolor(black)) ///
(rspike ll ul eventmonth if controls_included==1, lcolor(gs12)) (scatter b eventmonth if controls_included == 1, mcolor(black)), ///
yline(0) xlabel(-7(1)11, val angle(45))  xtitle(Month) title(`title') subtitle("Percent Change in Cumulative New Diagnosis Rate", position(11) span) ///
legend(order(2 "No Controls" 4 "Child and Adult General Exam Controls") rows(1))


**************
end
**************	

*By Opening Level

capture program drop estudybyopening
**************
program define estudybyopening
**************  
syntax , title(string) depvar(varlist) absorbvars(string) [weight(string)] [controls(varlist)] [controls2(varlist)]

gen openlow = open_group == 1 if open_group!=.
gen openmed = open_group == 2 if open_group!=.
gen openhigh = open_group == 3 if open_group!=.

foreach num of numlist 1/6 8/19  {
gen _TLC_`num' = _Texp_`num'*openlow
gen _TMC_`num' = _Texp_`num'*openmed
gen _THC_`num' = _Texp_`num'*openhigh
}

capture mat drop _all
mat month = -7\-6\-5\-4\-3\-2\0\1\2\3\4\5\6\7\8\9\10\11\-7\-6\-5\-4\-3\-2\0\1\2\3\4\5\6\7\8\9\10\11\-7\-6\-5\-4\-3\-2\0\1\2\3\4\5\6\7\8\9\10\11\.\.\.\.\.\.\.\.
mat coln month = month


ppmlhdfe `depvar' _TLC* _TMC* _THC* `controls' `controls2' `weight', absorb(`absorbvars') cluster(countycohort) eform

mat event = r(table)'
mat event = event , month 

capture drop _all
svmat event, names(col) 


replace b = b-1
replace ll = ll-1
replace ul = ul-1
gen ll_transformed = ll
gen ul_transformed = ul
replace ll = b-crit*se
replace ul = b+crit*se


gen group = 1 in 1/18
replace group = 2 in 19/36
replace group = 3 in 37/54

drop if month == .

set obs 57
replace b = 0 if month == .
replace month = -1 if month == .
replace group = 1 in 55
replace group = 2 in 56
replace group = 3 in 57

sort group month

label define eventmonth -7 "Aug" -6 "Sept" -5 "Oct" -4 "Nov" -3 "Dec" -2 "Jan" -1 "Feb" 0 "Mar" 1 "Apr" 2 "May" 3 "Jun" 4 "Jul" 5 "Aug" 6 "Sep" 7 "Oct" 8 "Nov" 9 "Dec" 10 "Jan" 11 "Feb", replace
lab val month eventmonth 

gen eventmonth = month-.2 if group==1
replace eventmonth = month if group==2
replace eventmonth = month+.2 if group==3

lab val eventmonth eventmonth


tw (rspike ll ul eventmonth  if group==1, lcolor(gs12)) (scatter b eventmonth if group==1, mcolor(black) msymbol(circle_hollow)) ///
(rspike ll ul eventmonth  if group==2, lcolor(gs12)) (scatter b eventmonth if group==2, mcolor(black) msymbol(diamond_hollow)) ///
(rspike ll ul eventmonth  if group==3, lcolor(gs12)) (scatter b eventmonth if group==3, mcolor(black) msymbol(triangle_hollow)), ///
yline(0) xlabel(-7(1)11, val angle(45))  xtitle(Month) title(`title') subtitle("Percent Change in Cumulative New Diagnosis Rate", position(11) span) ///
legend(order(2 "Low Opening Schools" 4 "Medium Opening Schools" 6 "High Opening Schools") rows(1))

**************
end
**************	


*Overall
foreach m of numlist 0/1 {
preserve
keep if  male == `m'
if `m'==1 estudy, title("Boys") depvar(adhd_new_cum) absorbvars(i.monthnum i.cohort2 i.county_fips i.grade) controls(well_child_visit_cum eval_rate_cum) controls2(white black hispanic medicaid private)  weight([w=cellsize])
if `m'==0 estudy, title("Girls") depvar(adhd_new_cum) absorbvars(i.monthnum i.cohort2 i.county_fips i.grade) controls(well_child_visit_cum eval_rate_cum) controls2(white black hispanic medicaid private) weight([w=cellsize])
graph rename m`m', replace
restore
}

grc1leg  m1 m0, ycommon

graph export "$output/figure7.eps", as(eps)  replace 


*By opening level
foreach m of numlist 0/1 {
preserve
keep if  male == `m'
drop if open_group == .
if `m'==1 estudybyopening, title("Boys") depvar(adhd_new_cum) absorbvars(i.monthnum#i.open_group i.cohort2#i.open_group i.monthnum i.cohort2 i.county_fips i.grade) controls(well_child_visit_cum eval_rate_cum) controls2(white black hispanic medicaid private)  weight([w=cellsize])
if `m'==0 estudybyopening, title("Girls") depvar(adhd_new_cum) absorbvars(i.monthnum#i.open_group i.cohort2#i.open_group i.monthnum i.cohort2 i.county_fips i.grade) controls(well_child_visit_cum eval_rate_cum) controls2(white black hispanic medicaid private) weight([w=cellsize])
graph rename m`m', replace
restore
}

grc1leg  m1 m0, ycommon
graph export "$output/figure8.eps", as(eps)  replace 

