# Optum DOD - Diagnosis Extracts 
# Individuals from 5 to 18 years old

library(arrow)
library(data.table)
library(fs)
library(plyr)
library(dplyr)
library(stringr)
library(xlsx)
library(haven)
library("rio")

rm(list=ls())

#-------- Exposed Cohort 2019-2021 --------#

quart <- list("2019q1","2019q2","2019q3","2019q4","2020q1",
              "2020q2","2020q3","2020q4","2021q1")

for (i in quart) {
  
  # Open diagnosis table
  assign(paste0("diag_diag",i), fread(paste0("/N/project/optum/data/raw/dodr/dod_diag",i,".txt.gz"), sep="|", header =TRUE, select =c("PATID", "DIAG", "ICD_FLAG", "FST_DT", "PAT_PLANID", "DIAG_POSITION","CLMID","LOC_CD")))
  # Keep only ADHD ICD codes
  assign(paste0("diag_diag",i), subset(get(paste0("diag_diag",i)), DIAG == "F900" | DIAG == "F901" | DIAG =="F902" | DIAG =="F908" | DIAG =="F909"))
  
  # Open table
  assign(paste0("med_m",i), fread(paste0("/N/project/optum/data/raw/dodr/dod_m",i,".txt.gz"), sep="|", header =TRUE, select =c("PATID","PAT_PLANID","CLMID","CLMSEQ","LOC_CD","FST_DT","PROV","PROVCAT")))
  assign(paste0("med_m",i), get(paste0("med_m",i))[order(PATID,FST_DT,CLMID,CLMSEQ),])
  assign(paste0("med_m",i), unique(setDT(get(paste0("med_m",i))),by=c("PATID","PAT_PLANID","FST_DT","CLMID","LOC_CD","PROV","PROVCAT")))
  
  # Merge Diag and Medical
  assign(paste0("diag_diag",i), merge(get(paste0("diag_diag",i)),get(paste0("med_m",i)), by=c("PATID","PAT_PLANID","CLMID","LOC_CD","FST_DT"), all.x=TRUE))
  rm(list=(paste0("med_m",i)))
  
  # Merge Diag and Provider bridge
  assign(paste0("prov_bridge"), fread(paste0("/N/project/optum/data/raw/dodr/dod_provider_bridge",".txt.gz"), sep="|", header =TRUE, select =c("PROV","PROV_UNIQUE","NPI")))
  assign(paste0("diag_diag",i), merge(get(paste0("diag_diag",i)),prov_bridge, by=c("PROV"), all.x=TRUE))
  rm(prov_bridge)
  
  # Merge Diag and Provider
  assign(paste0("provider"), fread(paste0("/N/project/optum/data/raw/dodr/dod_provider",".txt.gz"), sep="|", header =TRUE, select =c("PROV_UNIQUE","GRP_PRACTICE","HOSP_AFFIL","PROV_STATE","PROV_TYPE","TAXONOMY1","TAXONOMY2")))
  assign(paste0("diag_diag",i), merge(get(paste0("diag_diag",i)),provider, by=c("PROV_UNIQUE"), all.x=TRUE))
  rm(provider)
}

# Append datasets by quarter
diag1921 <- rbind(diag_diag2019q1,diag_diag2019q2,diag_diag2019q3,diag_diag2019q4,diag_diag2020q1,
                  diag_diag2020q2,diag_diag2020q3,diag_diag2020q4,diag_diag2021q1)
rm(diag_diag2019q1,diag_diag2019q2,diag_diag2019q3,diag_diag2019q4,diag_diag2020q1,
   diag_diag2020q2,diag_diag2020q3,diag_diag2020q4,diag_diag2021q1)

# Member continuous enrollment
members_co <-fread("/N/project/optum/data/raw/dodr/dod_mbr_co_enroll_r.txt.gz", 
                   sep="|", header =TRUE, select =c("PATID","PAT_PLANID","YRDOB","ELIGEFF","ELIGEND","GDR_CD"))
# Keep eligible patients by enrollment date
members_co <- subset(members_co,ELIGEFF<="2019-02-01" & ELIGEND>="2021-03-31",select=PATID:GDR_CD)
# Keep sample of children between 5-18 years old
members_co <-subset(members_co,YRDOB>=2002 & YRDOB<=2015)

## Merge DOD data
dod_df <-fread("/N/project/optum/data/raw/dodr/dod_mbr_enroll_r.txt.gz", 
               sep="|", header =TRUE, select =c("PATID","RACE","STATE","ELIGEFF","FAMILY_ID"))
# Sort by PATID and ELIGEFF, then Keep latest State and family ID
dod_df <- dod_df[order(dod_df$PATID,-dod_df$ELIGEFF),]
dod_df <- dod_df[!duplicated(dod_df$PATID),]
dod_df <- subset(dod_df,select = -c(ELIGEFF))
members_co <-merge(members_co,dod_df, by="PATID")
export(members_co,"/N/project/optum_freedman/Extracts/DOD/cohort_1921_exposed_dod.csv")

## Export file
merged1921 <-merge(diag1921,members_co, by="PATID")
export(merged1921,"/N/project/optum_freedman/Extracts/DOD/exposed_diag1921_dod.csv")
rm(list=ls())


#-------- Unexposed Cohort 2018-2020 --------#

quart <-list("2018q1","2018q2","2018q3","2018q4","2019q1",
             "2019q2","2019q3","2019q4","2020q1")

for (i in quart) {
  
  # Open diagnosis table
  assign(paste0("diag_diag",i), fread(paste0("/N/project/optum/data/raw/dodr/dod_diag",i,".txt.gz"), sep="|", header =TRUE, select =c("PATID", "DIAG", "ICD_FLAG", "FST_DT", "PAT_PLANID", "DIAG_POSITION","CLMID","LOC_CD")))
  # Keep only ADHD ICD codes
  assign(paste0("diag_diag",i), subset(get(paste0("diag_diag",i)), DIAG == "F900" | DIAG == "F901" | DIAG =="F902" | DIAG =="F908" | DIAG =="F909"))
  
  # Open Medical table
  assign(paste0("med_m",i), fread(paste0("/N/project/optum/data/raw/dodr/dod_m",i,".txt.gz"), sep="|", header =TRUE, select =c("PATID","PAT_PLANID","CLMID","CLMSEQ","LOC_CD","FST_DT","PROV","PROVCAT")))
  assign(paste0("med_m",i), get(paste0("med_m",i))[order(PATID,FST_DT,CLMID,CLMSEQ),])
  assign(paste0("med_m",i), unique(setDT(get(paste0("med_m",i))),by=c("PATID","PAT_PLANID","FST_DT","CLMID","LOC_CD","PROV","PROVCAT")))
  
  # Merge Diag and Medical
  assign(paste0("diag_diag",i), merge(get(paste0("diag_diag",i)),get(paste0("med_m",i)), by=c("PATID","PAT_PLANID","CLMID","LOC_CD","FST_DT"), all.x=TRUE))
  rm(list=(paste0("med_m",i)))
  
  # Merge Diag and Provider bridge
  assign(paste0("prov_bridge"), fread(paste0("/N/project/optum/data/raw/dodr/dod_provider_bridge",".txt.gz"), sep="|", header =TRUE, select =c("PROV","PROV_UNIQUE","NPI")))
  assign(paste0("diag_diag",i), merge(get(paste0("diag_diag",i)),prov_bridge, by=c("PROV"), all.x=TRUE))
  rm(prov_bridge)
  
  # Merge Diag and Provider
  assign(paste0("provider"), fread(paste0("/N/project/optum/data/raw/dodr/dod_provider",".txt.gz"), sep="|", header =TRUE, select =c("PROV_UNIQUE","GRP_PRACTICE","HOSP_AFFIL","PROV_STATE","PROV_TYPE","TAXONOMY1","TAXONOMY2")))
  assign(paste0("diag_diag",i), merge(get(paste0("diag_diag",i)),provider, by=c("PROV_UNIQUE"), all.x=TRUE))
  rm(provider)
}

# Append datasets by quarter
diag1820 <- rbind(diag_diag2018q1,diag_diag2018q2,diag_diag2018q3,diag_diag2018q4,diag_diag2019q1,
                  diag_diag2019q2,diag_diag2019q3,diag_diag2019q4,diag_diag2020q1)
rm(diag_diag2018q1,diag_diag2018q2,diag_diag2018q3,diag_diag2018q4,diag_diag2019q1,
   diag_diag2019q2,diag_diag2019q3,diag_diag2019q4,diag_diag2020q1)

# Members continuous enrollment
members_co <-fread("/N/project/optum/data/raw/dodr/dod_mbr_co_enroll_r.txt.gz", sep="|", header =TRUE, select =c("PATID", "PAT_PLANID","YRDOB","ELIGEFF","ELIGEND","GDR_CD"))
# Keep eligible patients by enrollment date
members_co <- subset(members_co,ELIGEFF<="2018-02-01" & ELIGEND>="2020-03-31",select=PATID:GDR_CD)
# Keep sample of children between 5-18 years old
members_co <-subset(members_co,YRDOB>=2002 & YRDOB<=2015)

## Merge DOD data
dod_df <-fread("/N/project/optum/data/raw/dodr/dod_mbr_enroll_r.txt.gz", sep="|", header =TRUE, select =c("PATID","RACE","STATE","ELIGEFF","FAMILY_ID"))
# Sort by PATID and ELIGEFF, then Keep latest State and family ID
dod_df <- dod_df[order(dod_df$PATID,-dod_df$ELIGEFF),]
dod_df <- dod_df[!duplicated(dod_df$PATID),]
dod_df <- subset(dod_df,select = -c(ELIGEFF))
members_co <-merge(members_co,dod_df, by="PATID")

export(members_co,"/N/project/optum_freedman/Extracts/DOD/cohort_1820_unexposed_dod.csv")
rm(dod_df)

## Export file
merged1820 <-merge(diag1820,members_co, by="PATID")
export(merged1820,"/N/project/optum_freedman/Extracts/DOD/unexposed_diag1820_dod.csv")
rm(list=ls())