# Optum DOD - CPT therapy Extracts
# Individuals from 5 to 18 years old

library(arrow)
library(data.table)
library(fs)
library(plyr)
library(dplyr)
library(stringr)
library(xlsx)
library(haven)
library(zoo)
library("rio")

#-------- Exposed Cohort 2019-2021 --------#

rm(list=ls())
quart <- list("2019q1","2019q2","2019q3","2019q4","2020q1",
              "2020q2","2020q3","2020q4","2021q1")

cpt_codes = c("90832","90833","90834","90836","90837","90838","90839","90840",
              "90845","90846","90847","90849","90853","90875","90876","90880")


for (i in quart) {
  
  # Open medical procedure table
  assign(paste0("med",i), fread(paste0("/N/project/optum/data/raw/dodr/dod_m",i,".txt.gz"), 
                                sep="|", header =TRUE, select =c("PATID","PAT_PLANID","CLMID","CLMSEQ","LOC_CD","FST_DT",
                                                                 "PROC_CD","PROCMOD","PROCMOD2","PROCMOD3","PROCMOD4","POS","PROV","PROVCAT")))
  # Keep CPT therapy codes
  assign(paste0("med",i), get(paste0("med",i))[PROC_CD %in% cpt_codes,])
  
}

# Append datasets by quarter
med1921 <- rbind(med2019q1,med2019q2,med2019q3,med2019q4,med2020q1,
                 med2020q2,med2020q3,med2020q4,med2021q1)
rm(med2019q1,med2019q2,med2019q3,med2019q4,med2020q1,
   med2020q2,med2020q3,med2020q4,med2021q1)

## Member continuous enrollment
members_co <-fread("/N/project/optum/data/raw/dodr/dod_mbr_co_enroll_r.txt.gz", sep="|", header =TRUE, select =c("PATID","YRDOB","ELIGEFF","ELIGEND","GDR_CD"))
# Keep eligible patients by enrollment date
members_co <- subset(members_co,ELIGEFF<="2019-02-01" & ELIGEND>="2021-03-31",select=PATID:GDR_CD)
# Keep sample of children between 5-18 years old
members_co <-subset(members_co,YRDOB>=2002 & YRDOB<=2015)

merged1921 <-merge(med1921,members_co, by="PATID")

## Telehealth Visits
merged1921[, visittype := case_when(PROCMOD == "95"~"TH",
                                    PROCMOD2 == "95"~"TH",
                                    PROCMOD3 == "95"~"TH",
                                    PROCMOD4 == "95"~"TH",
                                    POS == "02"~"TH",
                                    POS == "10"~"TH",
                                    TRUE~"InPerson")]

## Export file
export(merged1921,"/N/project/optum_freedman/Extracts/DOD/exposed_therapy1921_dod1.csv")
rm(list=ls())


#-------- Unexposed Cohort 2018-2020 --------#

quart <-list("2018q1","2018q2","2018q3","2018q4","2019q1",
             "2019q2","2019q3","2019q4","2020q1")

cpt_codes = c("90832","90833","90834","90836","90837","90838","90839","90840",
              "90845","90846","90847","90849","90853","90875","90876","90880")

for (i in quart) {
  
  # Open medical procedure table
  assign(paste0("med",i), fread(paste0("/N/project/optum/data/raw/dodr/dod_m",i,".txt.gz"), 
                                sep="|", header =TRUE, select =c("PATID","PAT_PLANID","CLMID","CLMSEQ","LOC_CD","FST_DT",
                                                                 "PROC_CD","PROCMOD","PROCMOD2","PROCMOD3","PROCMOD4","POS","PROV","PROVCAT")))
  # Keep CPT therapy codes
  assign(paste0("med",i), get(paste0("med",i))[PROC_CD %in% cpt_codes,])
  
}

# Append datasets by quarter
med1820 <- rbind(med2018q1,med2018q2,med2018q3,med2018q4,med2019q1,
                 med2019q2,med2019q3,med2019q4,med2020q1)
rm(med2018q1,med2018q2,med2018q3,med2018q4,med2019q1,
   med2019q2,med2019q3,med2019q4,med2020q1)

## Member continuous enrollment
members_co <-fread("/N/project/optum/data/raw/dodr/dod_mbr_co_enroll_r.txt.gz", sep="|", header =TRUE, select =c("PATID","YRDOB","ELIGEFF","ELIGEND","GDR_CD"))
# Keep eligible patients by enrollment date
members_co <- subset(members_co,ELIGEFF<="2018-02-01" & ELIGEND>="2020-03-31",select=PATID:GDR_CD)
# Keep sample of children between 5-18 years old
members_co <-subset(members_co,YRDOB>=2002 & YRDOB<=2015)

merged1820 <-merge(med1820,members_co, by="PATID")

## Telehealth Visits
merged1820[, visittype := case_when(PROCMOD == "95"~"TH",
                                    PROCMOD2 == "95"~"TH",
                                    PROCMOD3 == "95"~"TH",
                                    PROCMOD4 == "95"~"TH",
                                    POS == "02"~"TH",
                                    POS == "10"~"TH",
                                    TRUE~"InPerson")]

## Export file
export(merged1820,"/N/project/optum_freedman/Extracts/DOD/unexposed_therapy1820_dod1.csv")
rm(list=ls())