# Optum SES Extracts

library(arrow)
library(data.table)
library(fs)
library(plyr)
library(dplyr)
library(stringr)
library(xlsx)
library(haven)
library(dplyr)
library(data.table)
library("rio")

rm(list=ls())


#-------- Exposed Cohort 2019-2021 --------#

# Member continuous enrollment
members_co <-fread("/N/project/optum/data/raw/ses/ses_mbr_co_enroll.txt.gz", sep="|", header =TRUE, select =c("PATID", "PAT_PLANID","YRDOB","ELIGEFF","ELIGEND","GDR_CD"))
# Keep eligible patients by enrollment date
members_co <- subset(members_co,ELIGEFF<="2019-02-01" & ELIGEND>="2021-03-31",select=PATID:GDR_CD)
# Keep sample of children between 5-18 years old
members_co <-subset(members_co,YRDOB>=2002 & YRDOB<=2015)

## Merge SES data
ses_vars <- c("PATID","D_EDUCATION_LEVEL_CODE","D_FED_POVERTY_STATUS_CODE","D_HOME_OWNERSHIP_CODE",
              "D_HOUSEHOLD_INCOME_RANGE_CODE","NUM_ADULTS","NUM_CHILD","D_RACE_CODE")

ses_df <-fread("/N/project/optum/data/raw/ses/ses_ses.txt.gz", sep="|", header =TRUE, select = ses_vars)
members_co <-merge(members_co,ses_df, by="PATID")
export(members_co,"/N/project/optum_freedman/Extracts/SES/cohort_1921_exposed_ses.csv")
rm(ses_df)
gc()

## Diagnosis tables

quart <- list("2019q1","2019q2","2019q3","2019q4","2020q1",
              "2020q2","2020q3","2020q4","2021q1")

for (i in quart) {
  
  # Open diagnosis table
  assign(paste0("diag", i), fread(paste0("/N/project/optum/data/raw/ses_81_202207/ses_diag",i,".txt.gz"), sep="|", header =TRUE, select =c("PATID", "DIAG", "ICD_FLAG", "FST_DT", "PAT_PLANID", "DIAG_POSITION")))
  # Keep ADHD ICD codes
  assign(paste0("diag", i), subset(get(paste0("diag",i)), DIAG == "F900" | DIAG == "F901" | DIAG =="F902" | DIAG =="F908" | DIAG =="F909"))
}

# Append datasets by quarter
diag1921 <- rbind(diag2019q1,diag2019q2,diag2019q3,diag2019q4,diag2020q1,
                  diag2020q2,diag2020q3,diag2020q4,diag2021q1)
rm(diag2019q1,diag2019q2,diag2019q3,diag2019q4,diag2020q1,
   diag2020q2,diag2020q3,diag2020q4,diag2021q1)

merged1921 <- merge(diag1921,members_co, by="PATID")

## Export file
export(merged1921,"/N/project/optum_freedman/Extracts/SES/exposed_diag1921_ses.csv")
rm(list=ls())
gc()


#-------- Unexposed Cohort 2018-2020 --------#

rm(list=ls())
# Member continuous enrollment
members_co <-fread("/N/project/optum/data/raw/ses/ses_mbr_co_enroll.txt.gz", sep="|", header =TRUE, select =c("PATID","YRDOB","ELIGEFF","ELIGEND","GDR_CD"))
# Keep eligible patients by enrollment date
members_co <- subset(members_co,ELIGEFF<="2018-02-01" & ELIGEND>="2020-03-31",select=PATID:GDR_CD)
# Keep sample of children between 5-18 years old
members_co <-subset(members_co,YRDOB>=2002 & YRDOB<=2015)

## Merge SES data
ses_vars <- c("PATID","D_EDUCATION_LEVEL_CODE","D_FED_POVERTY_STATUS_CODE","D_HOME_OWNERSHIP_CODE",
              "D_HOUSEHOLD_INCOME_RANGE_CODE","NUM_ADULTS","NUM_CHILD","D_RACE_CODE")

ses_df <- fread("/N/project/optum/data/raw/ses/ses_ses.txt.gz", sep="|", header =TRUE, select = ses_vars)
members_co <- merge(members_co,ses_df, by="PATID")
export(members_co,"/N/project/optum_freedman/Extracts/SES/cohort_1820_unexposed_ses.csv")
rm(ses_df)
gc()

## Diagnosis tables

quart <-list("2018q1","2018q2","2018q3","2018q4","2019q1",
             "2019q2","2019q3","2019q4","2020q1")

for (i in quart) {
  
  # Open diagnosis table
  assign(paste0("diag", i), fread(paste0("/N/project/optum/data/raw/ses_81_202207/ses_diag",i,".txt.gz"), sep="|", header =TRUE, select =c("PATID","DIAG","ICD_FLAG","FST_DT","PAT_PLANID","DIAG_POSITION","CLMID","LOC_CD")))
  # Keep only ADHD ICD codes
  assign(paste0("diag", i), subset(get(paste0("diag",i)), DIAG == "F900" | DIAG == "F901" | DIAG =="F902" | DIAG =="F908" | DIAG =="F909"))
}

# Append datasets by quarter
diag1820 <- rbind(diag2018q1,diag2018q2,diag2018q3,diag2018q4,diag2019q1,
                  diag2019q2,diag2019q3,diag2019q4,diag2020q1)
rm(diag2018q1,diag2018q2,diag2018q3,diag2018q4,diag2019q1,
   diag2019q2,diag2019q3,diag2019q4,diag2020q1)

merged1820 <-merge(diag1820,members_co, by="PATID")

## Export file
export(merged1820,"/N/project/optum_freedman/Extracts/SES/unexposed_diag1820_ses.csv")
rm(list=ls())
gc()