
clear
set more off, perm



/**** Unexposed Cohort*****/
import delimited "$input/cohort_1820_unexposed_dod.csv", encoding(ISO-8859-1) clear

gen male = gdr_cd =="M"

*drop unnecesary variables, since this is going to get very large when expanded to panel
keep patid yrdob male state race

*creat monthly panel structure to evenutally merge in diagnoses by month
gen yrmo = ym(2018, 2)
format yrmo %tm
xtset patid yrmo, monthly
tsappend, add(25)
foreach var of varlist yrdob state male race  {
	by patid: replace `var' = `var'[1]
}

save "$intermediate/cohort1_prepped_for_diagmerge", replace


//Create monthly diagnosis data to merge back to panels.  
import delimited "$input/unexposed_diag1820_dod.csv", encoding(ISO-8859-1) clear
gen diagdate = date(fst_dt, "YMD")
gen yrmo = mofd(diagdate)
format yrmo %tm
*extract has an extra month
drop if yrmo == 696

*create ADHD indictor (1 for every row in this dataset) 
gen adhd = diag != ""
*telehealth indicator if we have teleheatlh info 
gen telehealth_diag = telehealth if any_em == 1
*first ADHD diagnosis 
sort patid diagdate
by patid: egen firstdiagdate = min(diagdate)

*ADHD diagnosis type
gen inat = diag == "F900" 
gen anyhyper = diag == "F901" | diag == "F902"
gen other = diag == "F908" | diag == "F909"

duplicates tag patid diagdate if diagdate == firstdiagdate, gen(dupfirst)

by patid: egen maxinat = max(inat) if diagdate==firstdiagdate
by patid: egen maxanyhyper = max(anyhyper) if diagdate==firstdiagdate
by patid: egen maxother = max(other) if diagdate==firstdiagdate

*ADHD diagnosis type for first diagnosis
gen anyhyper_first = maxanyhyper==1
gen inat_first = maxinat == 1 & maxanyhyper == 0
gen other_first = maxother == 1 & maxinat == 0 & maxanyhyper == 0

*telehealth for first diagnosis
gen telehealth_diag_first = telehealth_diag==1 & diagdate==firstdiagdate if any_em==1

*collapse to patient month level, taking max of each indicator in month
collapse (max) adhd telehealth_diag *_first, by(patid yrmo)
save "$intermediate/cohort1_adhd", replace


//Create monthly RX data to merge back to panels.  
import delimited "$input/unexposed_rx1820_dod.csv", encoding(ISO-8859-1) clear
gen rxdate = date(fill_dt, "YMD")
gen yrmo = mofd(rxdate)
format yrmo %tm
gen rx=1
collapse rx, by(patid yrmo)
save "$intermediate/cohort1_rx", replace

//Create monthly therapy visit data to merge back to panels.  
import delimited "$input/unexposed_therapy1820_dod.csv", encoding(ISO-8859-1) clear
gen therapydate = date(fst_dt, "YMD")
gen yrmo = mofd(therapydate)
format yrmo %tm
*any behavioral therapy visit
gen therapy = 1
*any telehealth therapy visit
gen telehealth_adhd = adhd == 1 & telehealth == 1
*collapse, including adhd behavioral therapy 
collapse therapy (max) telehealth therapy_adhd=adhd telehealth_adhd, by(patid yrmo)
save "$intermediate/cohort1_therapy", replace
  
//Create monthly well visit data to merge back to panels.  
import delimited "$input/unexposed_cpt1820_dod_archived.csv", encoding(ISO-8859-1) clear
gen welldate = date(fst_dt, "YMD")
gen yrmo = mofd(welldate)
format yrmo %tm
collapse (max) well_child_visit - develop_screening, by(patid yrmo)
save "$intermediate/cohort1_well", replace

 
//Prep Adult E&M visits by state and month 
import delimited "$input/cohort_adults_1820_unexposed_dod.csv", encoding(ISO-8859-1) clear

*Assign denominator - count of number of adults in the person's state - to each individual
bysort state: egen num_adults = count(patid)
keep patid state num_adults
save "$intermediate/adult_denominator1", replace
 
//Create monthly adult E&M visits by state
import delimited "$input/unexposed_cpteval1820_adults_dod.csv", encoding(ISO-8859-1) clear
gen welldate = date(fst_dt, "YMD")
gen yrmo = mofd(welldate)
format yrmo %tm
gen eval = 1
collapse (sum) eval, by(patid yrmo)
*merge denominator and state at patid level
merge m:1 patid using "$intermediate/adult_denominator1"
*collapse to state-month level
collapse (mean) num_adults (sum) eval, by(state yrmo)
drop if state == ""
*create rate of e&m visits
gen eval_rate = eval/num_adults
*create cumulative e&m visits per adult_denominator1
sort state yrmo
gen eval_rate_cum = eval_rate
by state: replace eval_rate_cum = eval_rate_cum[_n-1] + eval_rate if _n>1
save "$intermediate/adults1_eval", replace
 
//Merge all created person-month variables to full person-month panel. Fill in all indicator variables as 0 when no merge (no merge implies no visit that mopnth)
use "$intermediate/cohort1_prepped_for_diagmerge", clear
merge 1:1 patid yrmo using "$intermediate/cohort1_adhd", keep(match master)
foreach var of varlist adhd telehealth_diag *_first { 
replace `var'=0 if _merge == 1
}
drop _merge

merge 1:1 patid yrmo using "$intermediate/cohort1_rx", keep(match master)
replace rx=0 if rx==.
drop _merge

merge 1:1 patid yrmo using "$intermediate/cohort1_therapy", keep(match master)
replace therapy=0 if therapy==.
replace therapy_adhd=0 if therapy_adhd==.
replace telehealth=0 if telehealth==.
replace telehealth_adhd=0 if telehealth_adhd==.
drop _merge

merge 1:1 patid yrmo using "$intermediate/cohort1_well", keep(match master)
foreach var of varlist well_child_visit {
replace `var'=0 if `var'==.
}
drop _merge

merge m:1 state yrmo using "$intermediate/adults1_eval", keep(match master)

//Generate grades based on birth year
gen grade = 2013-yrdob 
//keep elementary school age children
keep if grade >=0 & grade <=5

//Save Unexposed Cohort
save "$intermediate/cohort1_merged", replace 
 

/**** Exposed Cohort*****/
import delimited "$input/cohort_1921_exposed_dod.csv", encoding(ISO-8859-1) clear

gen male = gdr_cd =="M"

*drop unnecesary variables, since this is going to get very large when expanded to panel
keep patid yrdob male state race

*creat monthly panel structure to evenutally merge in diagnoses by month
gen yrmo = ym(2019, 2)
format yrmo %tm
xtset patid yrmo, monthly
tsappend, add(25)
foreach var of varlist yrdob state male race  {
	by patid: replace `var' = `var'[1]
}

save "$intermediate/cohort2_prepped_for_diagmerge", replace


//Create monthly diagnosis data to merge back to panels.  
import delimited "$input/exposed_diag1921_dod.csv", encoding(ISO-8859-1) clear
gen diagdate = date(fst_dt, "YMD")
gen yrmo = mofd(diagdate)
format yrmo %tm
*extract has an extra month
drop if yrmo == 708

*create ADHD indictor (1 for every row in this dataset) 
gen adhd = diag != ""
*telehealth indicator if we have teleheatlh info 
gen telehealth_diag = telehealth if any_em == 1
*first ADHD diagnosis 
sort patid diagdate
by patid: egen firstdiagdate = min(diagdate)

*ADHD diagnosis type
gen inat = diag == "F900" 
gen anyhyper = diag == "F901" | diag == "F902"
gen other = diag == "F908" | diag == "F909"

duplicates tag patid diagdate if diagdate == firstdiagdate, gen(dupfirst)

by patid: egen maxinat = max(inat) if diagdate==firstdiagdate
by patid: egen maxanyhyper = max(anyhyper) if diagdate==firstdiagdate
by patid: egen maxother = max(other) if diagdate==firstdiagdate

*ADHD diagnosis type for first diagnosis
gen anyhyper_first = maxanyhyper==1
gen inat_first = maxinat == 1 & maxanyhyper == 0
gen other_first = maxother == 1 & maxinat == 0 & maxanyhyper == 0

*telehealth for first diagnosis
gen telehealth_diag_first = telehealth_diag==1 & diagdate==firstdiagdate if any_em==1

*collapse to patient month level, taking max of each indicator in month
collapse (max) adhd telehealth_diag *_first, by(patid yrmo)
save "$intermediate/cohort2_adhd", replace


//Create monthly RX data to merge back to panels.  
import delimited "$input/exposed_rx1921_dod.csv", encoding(ISO-8859-1) clear
gen rxdate = date(fill_dt, "YMD")
gen yrmo = mofd(rxdate)
format yrmo %tm
gen rx=1
collapse rx, by(patid yrmo)
save "$intermediate/cohort2_rx", replace

//Create monthly therapy visit data to merge back to panels.  
import delimited "$input/exposed_therapy1921_dod.csv", encoding(ISO-8859-1) clear
gen therapydate = date(fst_dt, "YMD")
gen yrmo = mofd(therapydate)
format yrmo %tm
*any behavioral therapy visit
gen therapy = 1
*any telehealth therapy visit
gen telehealth_adhd = adhd == 1 & telehealth == 1
*collapse, including adhd behavioral therapy 
collapse therapy (max) telehealth therapy_adhd=adhd telehealth_adhd, by(patid yrmo)
save "$intermediate/cohort2_therapy", replace
  
//Create monthly well visit data to merge back to panels.  
import delimited "$input/exposed_cpt1921_dod_archived.csv", encoding(ISO-8859-1) clear
gen welldate = date(fst_dt, "YMD")
gen yrmo = mofd(welldate)
format yrmo %tm
collapse (max) well_child_visit, by(patid yrmo)
save "$intermediate/cohort2_well", replace
 
//Prep Adult E&M visits by state and month 
import delimited "$input/cohort_adults_1921_exposed_dod.csv", encoding(ISO-8859-1) clear

*Assign denominator - count of number of adults in the person's state - to each individual
bysort state: egen num_adults = count(patid)
keep patid state num_adults
save "$intermediate/adult_denominator2", replace
 
//Create monthly adult E&M visits by state
import delimited "$input/exposed_cpteval1921_adults_dod.csv", encoding(ISO-8859-1) clear
gen welldate = date(fst_dt, "YMD")
gen yrmo = mofd(welldate)
format yrmo %tm
gen eval = 1
collapse (sum) eval, by(patid yrmo)
*merge denominator and state at patid level
merge m:1 patid using "$intermediate/adult_denominator2"
*collapse to state-month level
collapse (mean) num_adults (sum) eval, by(state yrmo)
drop if state == ""
*create rate of e&m visits
gen eval_rate = eval/num_adults
*create cumulative e&m visits per adult_denominator1
sort state yrmo
gen eval_rate_cum = eval_rate
by state: replace eval_rate_cum = eval_rate_cum[_n-1] + eval_rate if _n>1
save "$intermediate/adults2_eval", replace
 
//Merge all created person-month variables to full person-month panel. Fill in all indicator variables as 0 when no merge (no merge implies no visit that mopnth)
use "$intermediate/cohort2_prepped_for_diagmerge", clear
merge 1:1 patid yrmo using "$intermediate/cohort2_adhd", keep(match master)
foreach var of varlist adhd telehealth_diag *_first { 
replace `var'=0 if _merge == 1
}
drop _merge

merge 1:1 patid yrmo using "$intermediate/cohort2_rx", keep(match master)
replace rx=0 if rx==.
drop _merge

merge 1:1 patid yrmo using "$intermediate/cohort2_therapy", keep(match master)
replace therapy=0 if therapy==.
replace therapy_adhd=0 if therapy_adhd==.
replace telehealth=0 if telehealth==.
replace telehealth_adhd=0 if telehealth_adhd==.
drop _merge

merge 1:1 patid yrmo using "$intermediate/cohort2_well", keep(match master)
foreach var of varlist well_child_visit {
replace `var'=0 if `var'==.
}
drop _merge

merge m:1 state yrmo using "$intermediate/adults2_eval", keep(match master)

//Generate grades based on birth year
gen grade = 2014-yrdob
//keep elementary school age children
keep if grade >=0 & grade <=5

//Save exposed Cohort
save "$intermediate/cohort2_merged", replace 



/*****Append the 2 cohorts, and compelete data cleaning*****/ 
use "$intermediate/cohort1_merged", clear 
gen cohort = 1
append using "$intermediate/cohort2_merged"
replace cohort = 2 if cohort == .

*post pandemic dummy - after Mar of second year for each cohort
gen post = cohort==2 & yrmo>=ym(2020,3)
replace post = 1 if cohort==1 & yrmo>=ym(2019,3)

*Month in "event time"
sort cohort patid yrmo
bysort cohort patid: gen monthnum = _n
label define monthnum 1 "Feb" 2 "Mar" 3 "Apr" 4 "May" 5 "Jun" 6 "Jul" 7 "Aug" 8 "Sep" 9 "Oct" 10 "Nov" 11 "Dec" 12 "Jan" ///
13 "Feb" 14 "Mar" 15 "Apr" 16 "May" 17 "Jun" 18 "Jul" 19 "Aug" 20 "Sep" 21 "Oct" 22 "Nov" 23 "Dec" 24 "Jan" 25 "Feb" 26 "Mar" 
lab val monthnum monthnum

*Define 6 month lookback period
gen lookback = monthnum <=6

*any adhd in lookback period
by cohort patid: egen anyadhd_lba = max(adhd) if lookback==1
by cohort patid: egen anyadhd_lb = max(anyadhd_lba)
drop anyadhd_lba

*any dx in lookback period
by cohort patid: egen anyrx_lba = max(rx) if lookback==1
by cohort patid: egen anyrx_lb = max(anyrx_lba)
drop anyrx_lba

*new adhd diagnoses or rx
gen adhd_new = adhd==1 & anyadhd_lb==0
gen rx_new = rx==1 & anyrx_lb==0

*first time new diagnosis or rx occurs
foreach var of varlist adhd rx { 
gen monthnew`var' = monthnum if `var'_new==1
by cohort patid: egen firstmonth_new`var' = min(monthnew`var')
gen `var'_new_first = firstmonth_new`var' == monthnew`var' if monthnew`var'!=.
replace `var'_new_first = 0 if `var'_new_first==.
}

*Cumulative measure of first diagnosis and rx. Once it turns on, it stays ones
*adhdhyper adhdinat adhdother adhdhypermode adhdinatmode adhdothermode
foreach var of varlist adhd rx { 
gen `var'_new_cum = `var'_new_first
by cohort patid: replace `var'_new_cum = 1 if `var'_new_cum[_n-1]==1
}

*Separate cumulative new diagnoses into types: inatentive, anyhyper (hyper or combined), other
by cohort patid: egen inat_firstm = max(inat_first) 
by cohort patid: egen anyhyper_firstm = max(anyhyper_first)
by cohort patid: egen other_firstm = max(other_first)

gen inat_first_cum = adhd_new_cum == 1 & inat_firstm == 1  
gen anyhyper_first_cum = adhd_new_cum == 1 & anyhyper_firstm == 1
gen other_first_cum = adhd_new_cum == 1 & other_firstm == 1

*Cumulative measures of well child visits 
gen well_child_visit_cum = well_child_visit
by cohort patid: replace well_child_visit_cum = well_child_visit_cum[_n-1] + well_child_visit if _n>1

format patid %18.0f

*have an extra month we don't want
drop if monthnum == 26

encode race, gen(race_cat)
replace race_cat = 0 if race == ""

*drop if missing race/ethnicity info
drop if race_cat == 0

*Save individual level data set
save "$intermediate/adhd_individual", replace 
 
/****collapse into cells for regressions - cohort - gender - race - grade level - state by monthnumber (event time) - year 1 adhd status. year of birth, actual month, year number are also included and extraneous ***/
use "$intermediate/adhd_individual", clear 
bysort cohort male race_cat grade state monthnum yrdob yrmo anyadhd_lb: gen cellsize = _N
collapse adhd adhd*_new_first adhd*_new_cum *first_cum rx rx_new_first rx_new_cum  telehealth_diag telehealth_diag_first therapy therapy_adhd telehealth telehealth_adhd well_child_visit well_child_visit_cum eval_rate eval_rate_cum num_adults cellsize, by(cohort male race_cat grade state monthnum yrdob yrmo lookback anyadhd_lb) 

*clean up by dropping missing state or territories
drop if state =="" | state == "PR" | state == "UN" 

*Assign releative percent decrease in school visits based on Safegraph data   
gen pct_decrease_fall=.

replace pct_decrease_fall = 	0.58317		if state == 	"AK"
replace pct_decrease_fall = 	0.2154843	if state == 	"AL"
replace pct_decrease_fall = 	0.1810629	if state == 	"AR"
replace pct_decrease_fall = 	0.4618583	if state == 	"AZ"
replace pct_decrease_fall = 	0.7095355	if state == 	"CA"
replace pct_decrease_fall = 	0.3684454	if state == 	"CO"
replace pct_decrease_fall = 	0.3610999	if state == 	"CT"
replace pct_decrease_fall = 	0.6935388	if state == 	"DC"
replace pct_decrease_fall = 	0.5158976	if state == 	"DE"
replace pct_decrease_fall = 	0.4097833	if state == 	"FL"
replace pct_decrease_fall = 	0.2838393	if state == 	"GA"
replace pct_decrease_fall = 	0.5787637	if state == 	"HI"
replace pct_decrease_fall = 	0.2043966	if state == 	"IA"
replace pct_decrease_fall = 	0.3159273	if state == 	"ID"
replace pct_decrease_fall = 	0.4561658	if state == 	"IL"
replace pct_decrease_fall = 	0.1619578	if state == 	"IN"
replace pct_decrease_fall = 	0.2178313	if state == 	"KS"
replace pct_decrease_fall = 	0.4724085	if state == 	"KY"
replace pct_decrease_fall = 	0.1628256	if state == 	"LA"
replace pct_decrease_fall = 	0.5189056	if state == 	"MA"
replace pct_decrease_fall = 	0.6919493	if state == 	"MD"
replace pct_decrease_fall = 	0.3353405	if state == 	"ME"
replace pct_decrease_fall = 	0.4316188	if state == 	"MI"
replace pct_decrease_fall = 	0.3901888	if state == 	"MN"
replace pct_decrease_fall = 	0.212297	if state == 	"MO"
replace pct_decrease_fall = 	0.1609688	if state == 	"MS"
replace pct_decrease_fall = 	0.2701854	if state == 	"MT"
replace pct_decrease_fall = 	0.4720571	if state == 	"NC"
replace pct_decrease_fall = 	0.2122348	if state == 	"ND"
replace pct_decrease_fall = 	0.238357	if state == 	"NE"
replace pct_decrease_fall = 	0.378525	if state == 	"NH"
replace pct_decrease_fall = 	0.5243644	if state == 	"NJ"
replace pct_decrease_fall = 	0.633318	if state == 	"NM"
replace pct_decrease_fall = 	0.6431418	if state == 	"NV"
replace pct_decrease_fall = 	0.4175088	if state == 	"NY"
replace pct_decrease_fall = 	0.2680434	if state == 	"OH"
replace pct_decrease_fall = 	0.2961539	if state == 	"OK"
replace pct_decrease_fall = 	0.6248114	if state == 	"OR"
replace pct_decrease_fall = 	0.400594	if state == 	"PA"
replace pct_decrease_fall = 	0.4582612	if state == 	"RI"
replace pct_decrease_fall = 	0.3074632	if state == 	"SC"
replace pct_decrease_fall = 	0.1023514	if state == 	"SD"
replace pct_decrease_fall = 	0.2474896	if state == 	"TN"
replace pct_decrease_fall = 	0.3476795	if state == 	"TX"
replace pct_decrease_fall = 	0.308397	if state == 	"UT"
replace pct_decrease_fall = 	0.6852382	if state == 	"VA"
replace pct_decrease_fall = 	0.4062874	if state == 	"VT"
replace pct_decrease_fall = 	0.6351568	if state == 	"WA"
replace pct_decrease_fall = 	0.3659146	if state == 	"WI"
replace pct_decrease_fall = 	0.2955408	if state == 	"WV"
replace pct_decrease_fall = 	0.0778373	if state == 	"WY"

drop if pct_decrease_fall == .

gen sch_disrupt = .

replace sch_disrupt = 	0.0747976	if state == 	"AK"
replace sch_disrupt = 	0.1214384	if state == 	"AL"
replace sch_disrupt = 	0.109648	if state == 	"AR"
replace sch_disrupt = 	0.1592302	if state == 	"AZ"
replace sch_disrupt = 	0.0367313	if state == 	"CA"
replace sch_disrupt = 	0.106158	if state == 	"CO"
replace sch_disrupt = 	0.0946317	if state == 	"CT"
replace sch_disrupt = 	0.048192	if state == 	"DC"
replace sch_disrupt = 	0.1210556	if state == 	"DE"
replace sch_disrupt = 	0.0948559	if state == 	"FL"
replace sch_disrupt = 	0.0860867	if state == 	"GA"
replace sch_disrupt = 	0.1089319	if state == 	"HI"
replace sch_disrupt = 	0.0969967	if state == 	"IA"
replace sch_disrupt = 	0.0748847	if state == 	"ID"
replace sch_disrupt = 	0.0659502	if state == 	"IL"
replace sch_disrupt = 	0.0984567	if state == 	"IN"
replace sch_disrupt = 	0.0669373	if state == 	"KS"
replace sch_disrupt = 	0.113699	if state == 	"KY"
replace sch_disrupt = 	0.1403929	if state == 	"LA"
replace sch_disrupt = 	0.079875	if state == 	"MA"
replace sch_disrupt = 	0.0674867	if state == 	"MD"
replace sch_disrupt = 	0.0902794	if state == 	"ME"
replace sch_disrupt = 	0.1095557	if state == 	"MI"
replace sch_disrupt = 	0.0980477	if state == 	"MN"
replace sch_disrupt = 	0.0798344	if state == 	"MO"
replace sch_disrupt = 	0.0966331	if state == 	"MS"
replace sch_disrupt = 	0.128297	if state == 	"MT"
replace sch_disrupt = 	0.0756362	if state == 	"NC"
replace sch_disrupt = 	0.1761318	if state == 	"ND"
replace sch_disrupt = 	0.0789388	if state == 	"NE"
replace sch_disrupt = 	0.0831322	if state == 	"NH"
replace sch_disrupt = 	0.127109	if state == 	"NJ"
replace sch_disrupt = 	0.0522557	if state == 	"NM"
replace sch_disrupt = 	0.0781531	if state == 	"NV"
replace sch_disrupt = 	0.1140193	if state == 	"NY"
replace sch_disrupt = 	0.0717615	if state == 	"OH"
replace sch_disrupt = 	0.1072774	if state == 	"OK"
replace sch_disrupt = 	0.0714928	if state == 	"OR"
replace sch_disrupt = 	0.0828901	if state == 	"PA"
replace sch_disrupt = 	0.110672	if state == 	"RI"
replace sch_disrupt = 	0.0543267	if state == 	"SC"
replace sch_disrupt = 	0.1419657	if state == 	"SD"
replace sch_disrupt = 	0.1085084	if state == 	"TN"
replace sch_disrupt = 	0.0658581	if state == 	"TX"
replace sch_disrupt = 	0.08053		if state == 	"UT"
replace sch_disrupt = 	0.0412806	if state == 	"VA"
replace sch_disrupt = 	0.0769675	if state == 	"VT"
replace sch_disrupt = 	0.0633266	if state == 	"WA"
replace sch_disrupt = 	0.0718551	if state == 	"WI"
replace sch_disrupt = 	0.0942446	if state == 	"WV"
replace sch_disrupt = 	0.085984	if state == 	"WY"

*Make one observation per state to split states into equal groups on openness
preserve
bysort state: keep if _n==1
_pctile pct_decrease_fall, nq(3)
scalar cut_s1_1 = r(r1)
scalar cut_s1_2 = r(r2)
restore
*Create openness variables
gen open_group = 3
replace open_group = 2 if pct_decrease_fall >=cut_s1_1 & pct_decrease_fall < cut_s1_2 
replace open_group = 1 if pct_decrease_fall >=cut_s1_2 
gen openlow = open_group == 1
gen openmed = open_group == 2
gen openhigh = open_group == 3

capture drop cut_*

*Make one observation per state to split states into equal groups on stability
preserve
bysort state: keep if _n==1
_pctile sch_disrupt, nq(3)
scalar cut_s1_1 = r(r1)
scalar cut_s1_2 = r(r2)
restore
*Create stability variables
gen stable_group = 3 
replace stable_group = 2 if sch_disrupt >=cut_s1_1 & sch_disrupt < cut_s1_2
replace stable_group = 1 if sch_disrupt >=cut_s1_2
gen stablelow = stable_group == 1
gen stablemed = stable_group == 2
gen stablehigh = stable_group == 3

preserve 
collapse open_group, by(county_fips)
save "$intermediate/open_groups_states", replace
restore

gen cohort2 = cohort==2
gen post = monthnum >= 14
gen cohort2Xpost = cohort2*post 

egen statenum= group(state)
egen statecohort = group(state cohort)

lab define pandemic 1 "Pandemic" 
lab val cohort2Xpost pandemic

lab define open_group 1 "Low Opening" 2 "Medium Opening" 3 "High Opening"
lab val open_group open_group

lab define stable_group 1 "Low Stability" 2 "Medium Stability" 3 "High Stability"
lab val stable_group stable_group

lab define race_detail 0 "Unknown" 1 "Asian" 2 "Black" 3 "Hispanic" 4 "White"
lab val race_cat race_detail

save "$intermediate/adhd_cells", replace 
  
  count
stop
  
   *collapse into cells for regressions - cohort - gender - race - grade level - state by monthnumber (event time) - year 1 RX status. school type, year of birth, actual month, year number are also included and extraneous
  use "$intermediate/adhd_individual", clear 
  bysort cohort male race_cat  grade state monthnum yrdob yrmo anyrx_lb: gen cellsize = _N
  collapse rx rx_new_first rx_new_cum well_child_visit well_child_visit_cum immunization hearing_test vision_test develop_screening eval_rate eval_rate_cum num_adults cellsize , by(cohort male race_cat grade state monthnum yrdob yrmo lookback anyrx_lb) 
  

*clean up by dropping missing state or territories
drop if state =="" | state == "PR" | state == "UN" 

*Assign releative percent decrease in school visits based on Safegraph data   
gen pct_decrease_fall=.

replace pct_decrease_fall = 	0.58317		if state == 	"AK"
replace pct_decrease_fall = 	0.2154843	if state == 	"AL"
replace pct_decrease_fall = 	0.1810629	if state == 	"AR"
replace pct_decrease_fall = 	0.4618583	if state == 	"AZ"
replace pct_decrease_fall = 	0.7095355	if state == 	"CA"
replace pct_decrease_fall = 	0.3684454	if state == 	"CO"
replace pct_decrease_fall = 	0.3610999	if state == 	"CT"
replace pct_decrease_fall = 	0.6935388	if state == 	"DC"
replace pct_decrease_fall = 	0.5158976	if state == 	"DE"
replace pct_decrease_fall = 	0.4097833	if state == 	"FL"
replace pct_decrease_fall = 	0.2838393	if state == 	"GA"
replace pct_decrease_fall = 	0.5787637	if state == 	"HI"
replace pct_decrease_fall = 	0.2043966	if state == 	"IA"
replace pct_decrease_fall = 	0.3159273	if state == 	"ID"
replace pct_decrease_fall = 	0.4561658	if state == 	"IL"
replace pct_decrease_fall = 	0.1619578	if state == 	"IN"
replace pct_decrease_fall = 	0.2178313	if state == 	"KS"
replace pct_decrease_fall = 	0.4724085	if state == 	"KY"
replace pct_decrease_fall = 	0.1628256	if state == 	"LA"
replace pct_decrease_fall = 	0.5189056	if state == 	"MA"
replace pct_decrease_fall = 	0.6919493	if state == 	"MD"
replace pct_decrease_fall = 	0.3353405	if state == 	"ME"
replace pct_decrease_fall = 	0.4316188	if state == 	"MI"
replace pct_decrease_fall = 	0.3901888	if state == 	"MN"
replace pct_decrease_fall = 	0.212297	if state == 	"MO"
replace pct_decrease_fall = 	0.1609688	if state == 	"MS"
replace pct_decrease_fall = 	0.2701854	if state == 	"MT"
replace pct_decrease_fall = 	0.4720571	if state == 	"NC"
replace pct_decrease_fall = 	0.2122348	if state == 	"ND"
replace pct_decrease_fall = 	0.238357	if state == 	"NE"
replace pct_decrease_fall = 	0.378525	if state == 	"NH"
replace pct_decrease_fall = 	0.5243644	if state == 	"NJ"
replace pct_decrease_fall = 	0.633318	if state == 	"NM"
replace pct_decrease_fall = 	0.6431418	if state == 	"NV"
replace pct_decrease_fall = 	0.4175088	if state == 	"NY"
replace pct_decrease_fall = 	0.2680434	if state == 	"OH"
replace pct_decrease_fall = 	0.2961539	if state == 	"OK"
replace pct_decrease_fall = 	0.6248114	if state == 	"OR"
replace pct_decrease_fall = 	0.400594	if state == 	"PA"
replace pct_decrease_fall = 	0.4582612	if state == 	"RI"
replace pct_decrease_fall = 	0.3074632	if state == 	"SC"
replace pct_decrease_fall = 	0.1023514	if state == 	"SD"
replace pct_decrease_fall = 	0.2474896	if state == 	"TN"
replace pct_decrease_fall = 	0.3476795	if state == 	"TX"
replace pct_decrease_fall = 	0.308397	if state == 	"UT"
replace pct_decrease_fall = 	0.6852382	if state == 	"VA"
replace pct_decrease_fall = 	0.4062874	if state == 	"VT"
replace pct_decrease_fall = 	0.6351568	if state == 	"WA"
replace pct_decrease_fall = 	0.3659146	if state == 	"WI"
replace pct_decrease_fall = 	0.2955408	if state == 	"WV"
replace pct_decrease_fall = 	0.0778373	if state == 	"WY"

drop if pct_decrease_fall == .

gen sch_disrupt = .

replace sch_disrupt = 	0.0747976	if state == 	"AK"
replace sch_disrupt = 	0.1214384	if state == 	"AL"
replace sch_disrupt = 	0.109648	if state == 	"AR"
replace sch_disrupt = 	0.1592302	if state == 	"AZ"
replace sch_disrupt = 	0.0367313	if state == 	"CA"
replace sch_disrupt = 	0.106158	if state == 	"CO"
replace sch_disrupt = 	0.0946317	if state == 	"CT"
replace sch_disrupt = 	0.048192	if state == 	"DC"
replace sch_disrupt = 	0.1210556	if state == 	"DE"
replace sch_disrupt = 	0.0948559	if state == 	"FL"
replace sch_disrupt = 	0.0860867	if state == 	"GA"
replace sch_disrupt = 	0.1089319	if state == 	"HI"
replace sch_disrupt = 	0.0969967	if state == 	"IA"
replace sch_disrupt = 	0.0748847	if state == 	"ID"
replace sch_disrupt = 	0.0659502	if state == 	"IL"
replace sch_disrupt = 	0.0984567	if state == 	"IN"
replace sch_disrupt = 	0.0669373	if state == 	"KS"
replace sch_disrupt = 	0.113699	if state == 	"KY"
replace sch_disrupt = 	0.1403929	if state == 	"LA"
replace sch_disrupt = 	0.079875	if state == 	"MA"
replace sch_disrupt = 	0.0674867	if state == 	"MD"
replace sch_disrupt = 	0.0902794	if state == 	"ME"
replace sch_disrupt = 	0.1095557	if state == 	"MI"
replace sch_disrupt = 	0.0980477	if state == 	"MN"
replace sch_disrupt = 	0.0798344	if state == 	"MO"
replace sch_disrupt = 	0.0966331	if state == 	"MS"
replace sch_disrupt = 	0.128297	if state == 	"MT"
replace sch_disrupt = 	0.0756362	if state == 	"NC"
replace sch_disrupt = 	0.1761318	if state == 	"ND"
replace sch_disrupt = 	0.0789388	if state == 	"NE"
replace sch_disrupt = 	0.0831322	if state == 	"NH"
replace sch_disrupt = 	0.127109	if state == 	"NJ"
replace sch_disrupt = 	0.0522557	if state == 	"NM"
replace sch_disrupt = 	0.0781531	if state == 	"NV"
replace sch_disrupt = 	0.1140193	if state == 	"NY"
replace sch_disrupt = 	0.0717615	if state == 	"OH"
replace sch_disrupt = 	0.1072774	if state == 	"OK"
replace sch_disrupt = 	0.0714928	if state == 	"OR"
replace sch_disrupt = 	0.0828901	if state == 	"PA"
replace sch_disrupt = 	0.110672	if state == 	"RI"
replace sch_disrupt = 	0.0543267	if state == 	"SC"
replace sch_disrupt = 	0.1419657	if state == 	"SD"
replace sch_disrupt = 	0.1085084	if state == 	"TN"
replace sch_disrupt = 	0.0658581	if state == 	"TX"
replace sch_disrupt = 	0.08053		if state == 	"UT"
replace sch_disrupt = 	0.0412806	if state == 	"VA"
replace sch_disrupt = 	0.0769675	if state == 	"VT"
replace sch_disrupt = 	0.0633266	if state == 	"WA"
replace sch_disrupt = 	0.0718551	if state == 	"WI"
replace sch_disrupt = 	0.0942446	if state == 	"WV"
replace sch_disrupt = 	0.085984	if state == 	"WY"

*Make one observation per state to split states into equal groups on openness
preserve
bysort state: keep if _n==1
_pctile pct_decrease_fall, nq(3)
scalar cut_s1_1 = r(r1)
scalar cut_s1_2 = r(r2)
restore
*Create openness variables
gen open_group = 3
replace open_group = 2 if pct_decrease_fall >=cut_s1_1 & pct_decrease_fall < cut_s1_2 
replace open_group = 1 if pct_decrease_fall >=cut_s1_2 
gen openlow = open_group == 1
gen openmed = open_group == 2
gen openhigh = open_group == 3

capture drop cut_*

*Make one observation per state to split states into equal groups on stability
preserve
bysort state: keep if _n==1
_pctile sch_disrupt, nq(3)
scalar cut_s1_1 = r(r1)
scalar cut_s1_2 = r(r2)
restore
*Create stability variables
gen stable_group = 3 
replace stable_group = 2 if sch_disrupt >=cut_s1_1 & sch_disrupt < cut_s1_2
replace stable_group = 1 if sch_disrupt >=cut_s1_2
gen stablelow = stable_group == 1
gen stablemed = stable_group == 2
gen stablehigh = stable_group == 3


gen cohort2 = cohort==2
gen post = monthnum >= 14
gen cohort2Xpost = cohort2*post 

egen statenum= group(state)
egen statecohort = group(state cohort)

lab define pandemic 1 "Pandemic" 
lab val cohort2Xpost pandemic

lab define open_group 1 "Low Opening" 2 "Medium Opening" 3 "High Opening"
lab val open_group open_group

lab define stable_group 1 "Low Stability" 2 "Medium Stability" 3 "High Stability"
lab val stable_group stable_group

lab define race_detail 0 "Unknown" 1 "Asian" 2 "Black" 3 "Hispanic" 4 "White"
lab val race_cat race_detail

  
   save "$intermediate/rx_cells", replace 

 
