/**** Event Study RX, with and without general utilization controls****/

use "$intermediate/rx_cells", clear
keep if lookback==0
keep if anyrx_lb==0

*set up event time variables with -1 as omitted time
gen exp = monthnum-14 if cohort==2
recode exp (.=-1)
char exp[omit] -1
xi i.exp, pref(_T)

capture program drop estudy
**************
program define estudy
**************  
syntax , title(string) depvar(varlist) absorbvars(string) [weight(string)] controls(varlist)

*set up month matrix
capture mat drop _all
mat month = -7\-6\-5\-4\-3\-2\0\1\2\3\4\5\6\7\8\9\10\11\.\-7\-6\-5\-4\-3\-2\0\1\2\3\4\5\6\7\8\9\10\11\.\.\.
mat coln month = month

*no controls
ppmlhdfe `depvar' _Texp* `weight', absorb(`absorbvars') cluster(statecohort) eform

mat event1 = r(table)'

*with controls
ppmlhdfe `depvar' _Texp* `controls' `weight', absorb(`absorbvars') cluster(statecohort) eform

mat event2 = r(table)'

*append results into single matrix 
mat event = event1 \ event2

mat event = event , month  

capture drop _all
svmat event, names(col) 

*confidence intervals
replace b = b-1
replace ll = ll-1
replace ul = ul-1
gen ll_transformed = ll
gen ul_transformed = ul
replace ll = b-crit*se
replace ul = b+crit*se

drop if month == .

gen controls_included = 0 in 1/18
replace controls_included =1 in 19/36

*add in row for reference period (-1) 
set obs 38
replace b = 0 if month == .
replace month = -1 if month == .
replace controls_included = 0 in 37
replace controls_included = 1 in 38

label define eventmonth -7 "Aug" -6 "Sept" -5 "Oct" -4 "Nov" -3 "Dec" -2 "Jan" -1 "Feb" 0 "Mar" 1 "Apr" 2 "May" 3 "Jun" 4 "Jul" 5 "Aug" 6 "Sep" 7 "Oct" 8 "Nov" 9 "Dec" 10 "Jan" 11 "Feb", replace
lab val month eventmonth 

gen eventmonth = month-.1 if controls_included==0
replace eventmonth = month+.1 if controls_included==1

lab val eventmonth eventmonth

sort controls_included eventmonth

tw (rspike ll ul eventmonth if controls_included==0, lcolor(gs12)) (scatter b eventmonth if controls_included == 0, mcolor(black)) ///
(rspike ll ul eventmonth if controls_included==1, lcolor(gs12)) (scatter b eventmonth if controls_included == 1, mcolor(black)), ///
yline(0) xlabel(-7(1)11, val angle(45))  xtitle(Month) title(`title') subtitle("Percent Change in Cumulative New Diagnosis Rate", position(11) span) ///
legend(order(2 "No Controls" 4 "Well-Child and Adult E&M Controls") rows(1))

**************
end
**************	

*Boys
preserve
keep if male == 1
estudy, title("Boys") depvar(rx_new_cum) absorbvars(i.monthnum i.cohort2 i.statenum i.grade i.race_cat) weight([w=cellsize]) controls(well_child_visit_cum eval_rate_cum )
graph rename boys, replace
restore

*Girls
preserve
keep if male == 0
estudy, title("Girls") depvar(rx_new_cum) absorbvars(i.monthnum i.cohort2 i.statenum i.grade i.race_cat) weight([w=cellsize]) controls(well_child_visit_cum eval_rate_cum )
graph rename girls, replace
restore

grc1leg  boys girls, ycommon
graph export "$output/figureB2.eps", as(eps)  replace 






