/**** Event Study, by race/ethnicity ****/

use "$intermediate/adhd_cells", clear
keep if lookback==0
keep if anyadhd_lb==0

*set up event time variables with -1 as omitted time
gen exp = monthnum-14 if cohort==2
recode exp (.=-1)
char exp[omit] -1
xi i.exp, pref(_T)
capture program drop estudybyrace
**************
program define estudybyrace
**************  
syntax , title(string) depvar(varlist) absorbvars(string) [weight(string)] controls(varlist)

foreach num of numlist 1/6 8/19  {
gen _TA_`num' = _Texp_`num'*(race_cat==1)
gen _TB_`num' = _Texp_`num'*(race_cat==2)
gen _TH_`num' = _Texp_`num'*(race_cat==3)
gen _TW_`num' = _Texp_`num'*(race_cat==4)
}

capture mat drop _all
mat month = -7\-6\-5\-4\-3\-2\0\1\2\3\4\5\6\7\8\9\10\11\-7\-6\-5\-4\-3\-2\0\1\2\3\4\5\6\7\8\9\10\11\-7\-6\-5\-4\-3\-2\0\1\2\3\4\5\6\7\8\9\10\11\-7\-6\-5\-4\-3\-2\0\1\2\3\4\5\6\7\8\9\10\11\.\.\.
mat coln month = month

ppmlhdfe `depvar'  _TA* _TB* _TH* _TW* `controls'  `weight', absorb(`absorbvars') cluster(statecohort) eform

mat event = r(table)'
mat event = event , month 


capture drop _all
svmat event, names(col) 

replace b = b-1
replace ll = ll-1
replace ul = ul-1
gen ll_transformed = ll
gen ul_transformed = ul
replace ll = b-crit*se
replace ul = b+crit*se

gen group = 1 in 1/18
replace group = 2 in 19/36
replace group = 3 in 37/54
replace group = 4 in 55/72

drop if month == .

set obs 76
replace b = 0 if month == .
replace month = -1 if month == .
replace group = 1 in 73
replace group = 2 in 74
replace group = 3 in 75
replace group = 4 in 76


sort group month

label define eventmonth -7 "Aug" -6 "Sept" -5 "Oct" -4 "Nov" -3 "Dec" -2 "Jan" -1 "Feb" 0 "Mar" 1 "Apr" 2 "May" 3 "Jun" 4 "Jul" 5 "Aug" 6 "Sep" 7 "Oct" 8 "Nov" 9 "Dec" 10 "Jan" 11 "Feb", replace
lab val month eventmonth 


gen eventmonth = month-.2 if group==4
replace eventmonth = month - .0667 if group==2
replace eventmonth = month+.0667 if group==3
replace eventmonth = month+.2 if group==1

lab val eventmonth eventmonth

tw (rspike ll ul eventmonth  if group==4, lcolor(gs12)) (scatter b eventmonth if group==4, mcolor(black) msymbol(circle_hollow))  ///
(rspike ll ul eventmonth  if group==2, lcolor(gs12)) (scatter b eventmonth if group==2, mcolor(black) msymbol(triangle_hollow)) /// 
(rspike ll ul eventmonth  if group==3, lcolor(gs12)) (scatter b eventmonth if group==3, mcolor(black) msymbol(square_hollow)) ///
(rspike ll ul eventmonth  if group==1, lcolor(gs12)) (scatter b eventmonth if group==1, mcolor(black) msymbol(diamond_hollow)) if eventmonth > -5.8 , /// 
yline(0) xlabel(-5(1)11, val angle(45))  xtitle(Month) title(`title') subtitle("Percent Change in Cumulative New Diagnosis Rate", position(11) span) ///
legend(order(2 "White" 4 "Black" 6 "Hispanic" 8 "Asian") rows(1))


**************
end
**************	


preserve
keep if male == 1
estudybyrace, title("Boys") depvar(adhd_new_cum) absorbvars(i.monthnum#i.race_cat i.cohort2#i.race_cat i.statenum i.grade) weight([w=cellsize]) controls(well_child_visit_cum eval_rate_cum )
graph rename boys, replace
restore

preserve
keep if male == 0
estudybyrace, title("Girls") depvar(adhd_new_cum) absorbvars(i.monthnum#i.race_cat i.cohort2#i.race_cat i.statenum i.grade) weight([w=cellsize]) controls(well_child_visit_cum eval_rate_cum )
graph rename girls, replace
restore

grc1leg  boys girls, ycommon
graph export "$output/figureB7.eps", as(eps)  replace 
