*Inputs: 
	*SafeGraph: monthlySchool_mobility.dta and ziptract_elementary.dta
	*CSDH: state_enrollment_alldistrict_pct.dta, state_enrollment_5kdistrict_pct.dta, state_enrollment_pct.dta, indiana_enrollment_pct_v3.dta
*Outputs: FigureA1.pdf, FigureA2.pdf, log file 

cap log close
log using "Appendix-A-Log.log", replace
	
*************************************
*PART 1: Nationwide Analysis
*************************************

clear 
qui{
use "schools/cleaned_schools/monthlySchool_mobility.dta"

keep if elem_sch==1
drop if year==2021
keep if inlist(month,9,10,11)
keep year month state school_visits 

reshape wide school_visits, i(state month) j(year)
gen rel_open=school_visits2020/school_visits2019
collapse (mean) rel_open, by(state)

****merge with CSDH data 
*all districts- 19 states total, pct fall weeks/months open 
merge 1:1 state using "schools/cleaned_schools/state_enrollment_alldistrict_percent.dta"
drop if _merge==2
rename in_person pct_weeks_open
rename virtual pct_weeks_closed
rename hybrid pct_weeks_hybrid

gen data_level=""
replace data_level="district" if _merge==3

keep state rel_open pct_* data_level

*5k districts- 8 states total 
merge 1:1 state using "schools/cleaned_schools/state_enrollment_5kdistrict_percent.dta"
drop if _merge==2
replace pct_weeks_open=in_person if _merge==3
replace pct_weeks_closed=virtual if _merge==3
replace pct_weeks_hybrid=hybrid if _merge==3

replace data_level="district_elem" if _merge==3

keep state rel_open pct_* data_level

*school level- 32 total 
merge 1:1 state using "schools/cleaned_schools/state_enrollment_percent.dta"
drop if _merge==2
replace pct_weeks_open=in_person if _merge==3
replace pct_weeks_closed=virtual if _merge==3
replace pct_weeks_hybrid=hybrid if _merge==3

replace data_level="school_elem" if _merge==3
keep state rel_open pct_* data_level
}



*************
*rank_rank compare graph

*drop if state=="HI"  | state=="AK" | data_level==""
drop if data_level==""
tab data_level

cap graph drop _all

sort rel_open
egen SG_rank=group(rel_open)
sort pct_weeks_open
egen P_rank=group(pct_weeks_open)
corr P_rank SG_rank

twoway scatter P_rank SG_rank, mcolor(navy) || function y=x, range(SG_rank) legend(off) ///
ytitle("In-Person Policy Rank") xtitle("SafeGraph Mobility Rank")  ///
text(1 35 "Corr=.813")  title("") scheme(s1color)
graph export "Figure-A1.pdf", replace

*************************************
*PART 2: Indiana Analysis
*************************************

clear


*for each zip-tract, get mean_mobility across schools (and save each school)
use "schools/cleaned_schools/ziptract_elementary.dta"

drop sd_*
drop mean_visits*
foreach v of varlist mean_mobility1-mean_mobility10 {
    replace `v' = 0 if `v'==.
  } 
foreach v of varlist new_share1-new_share10 {
    replace `v' = 0 if `v'==.
  } 

gen mean_mobility_final=mean_mobility1*new_share1+ ///
	mean_mobility2*new_share2 + ///
	mean_mobility3*new_share3 + ///
	mean_mobility4*new_share4 + ///
	mean_mobility5*new_share5 + ///
	mean_mobility6*new_share6 + ///
	mean_mobility7*new_share7 + ///
	mean_mobility8*new_share8 + ///
	mean_mobility9*new_share9 + ///
	mean_mobility10*new_share10
	
keep zip_code census_tract mean_mobility_final ncess* new_share*
gen SG_decile_full=1
sort mean_mobility_final 
forvalues i=2/10{
	replace SG_decile_full=`i' if _n>412.2*(`i'-1)
}
su

order zip_code census_tract mean_mobility_final SG_decile_full

tempfile zip_tract_construct
save `zip_tract_construct'

*now merge in the school percent fall in person variable 
clear 
forvalues i=1/10{
clear
use "schools/cleaned_schools/indiana_oster_enrollment.dta"
keep ncessch in_person hybrid virtual
rename ncessch ncessch`i'
merge 1:m ncessch`i' using `zip_tract_construct'
drop _merge
rename in_person pct_inperson`i'
rename hybrid pct_hybrid`i'
rename virtual pct_virtual`i'
save `zip_tract_construct', replace 
}

*now clean up and get zip_tract mean in person variable from CSDH
drop if zip_code==.
drop if census_tract==.
drop if mean_mobility_final==.

order zip_code census_tract mean_mobility_final 
su  pct_inperson1 mean_mobility_final

forvalues v=1/10{
	replace pct_inperson`v'=0 if new_share`v'==0
	drop if pct_inperson`v'==.
	*replace pct_hybrid`v'=0 if new_share`v'==0
	*drop if pct_hybrid`v'==.
	*replace pct_virtual`v'=0 if new_share`v'==0
	*drop if pct_virtual`v'==.
}

foreach varlead in inperson  {
gen `varlead'_final=pct_`varlead'1*new_share1+ ///
	pct_`varlead'2*new_share2 + ///
	pct_`varlead'3*new_share3 + ///
	pct_`varlead'4*new_share4 + ///
	pct_`varlead'5*new_share5 + ///
	pct_`varlead'6*new_share6 + ///
	pct_`varlead'7*new_share7 + ///
	pct_`varlead'8*new_share8 + ///
	pct_`varlead'9*new_share9 + ///
	pct_`varlead'10*new_share10
}

	
keep zip_code census_tract *_final SG_decile_full


*****************
*box-and-whisker: put safegraph into deciles, plot box and whisker of CSHD

graph box inperson_final, over(SG_decile_full) noout ytitle("In-Person Policy Share", size(medium)) medtype(cline) medline(lcolor(red)) ylabel(0(.2)1, nogrid) scheme(s1color) title("SafeGraph Mobility Decile", ring(3) pos(6) size(medium)) box(1, color(navy))
graph export "Figure-A2.pdf", replace


log close 
