
clear all
set more off, perm
set type double, perm

gl layers "schools/Indiana Schools/Merged layers"
gl school "schools/rawdata_schools"
gl output "schools/cleaned_schools"

*** Keep Indiana schools and their catchment areas
 
gl keep_vars = "ncessch zcta5ce10 geoid area int_area"
 
* Elementary schools
import delimited "$layers/primary_int.csv", clear
drop if ncessch == . | int_area == .
keep if inrange(zcta5ce10,46001,47997)
keep if stabbrev=="IN"
drop if area == 0
keep $keep_vars
order $keep_vars
 
// Merge school data
preserve
   use "$school/schoolData_IN.dta", clear
   egen tot_enroll = rowtotal(prekind2021 kind2021 grade12021 grade22021 grade32021 grade42021 grade52021 grade62021 grade72021 grade82021 grade92021 grade102021 grade112021 grade122021)
   drop if tot_enroll == 0
   keep ncessch low_grade high_grade tot_enroll
   tempfile nces
   save `nces'
restore

merge m:1 ncessch using `nces', nogen keep(match) keepusing(ncessch low_grade high_grade tot_enroll)
drop if low_grade=="10th Grade"
 
// Merge mobility data
merge m:1 ncessch using "$school/mobility_IN_fall20.dta", nogen keep(match)
 
gen share_area = int_area/area
 
// If schools overlap by geography, keep the one with more students (enrollment)
duplicates tag zcta5ce10 geoid low_grade high_grade share_area, gen(D)
gen enrollsh= tot_enroll*share_area
egen max1=max(enrollsh) if D>=1, by(zcta5ce10 geoid)
drop if enrollsh< max1 & D>=1
 
drop D enrollsh max1
egen id = group(zcta5ce10 geoid) 
gsort id -share_area
egen seq=seq(), by(id)

// Rescale area
egen totarea = sum(share_area), by(id)
gen new_share = share_area/totarea
 
drop area int_area low_grade high_grade tot_enroll share_area totarea
reshape wide ncessch new_share mean_mobility sd_mobility mean_visits19 mean_visits20, i(zcta5ce10 geoid) j(seq)
ren (zcta5ce10 geoid) (zip_code census_tract)
drop id
 
save "$output/ziptract_elementary.dta", replace
