
clear all
set more off, perm

gl urban "schools/Urban Institute"
gl safeg "schools/Safegraph patterns"
gl output "schools/cleaned_schools"


*** Merge schools' characteristics to geographic data

 use "$safegraph/urban_safegraph_merge.dta", clear
 
 keep if _merge == 3
 keep ncessch safegraph_place_id
 
// Directory data (Urban Institute)
preserve
  import delimited "$urban/schools_ccd_directory.csv", clear 
  keep if year==2016
  drop if state_location == "PR" | state_location == "GU" | state_location == "AS" | state_location == "VI"| state_location == "MP"
  keep ncessch elem_cedp middle_cedp high_cedp
  tempfile directory
  save `directory', replace
restore
 
 merge 1:1 ncessch using `directory', keep(match master) nogen
 tempfile urban
 save `urban', replace

*** Merge to Safegraph data

// 2019 mobility
use "$safeg/patterns_schoolsLong_2019.dta", clear
merge m:1 safegraph_place_id using `urban', keep(match using) nogen

gen week = week(date)
gen month = month(date)
drop if date == .
 
// Type of school
gen elem_sch = 1 if elem_cedp==1 & middle_cedp==0 & high_cedp==0
gen midd_sch = 1 if elem_cedp==0 & middle_cedp==1 & high_cedp==0
gen high_sch = 1 if elem_cedp==0 & middle_cedp==0 & high_cedp==1
gen elem_midd_sch = 1 if elem_cedp==1 & middle_cedp==1 & high_cedp==0
gen midd_high_sch = 1 if elem_cedp==0 & middle_cedp==1 & high_cedp==1
gen elmidhi_sch = 1 if elem_cedp==1 & middle_cedp==1 & high_cedp==1
 
foreach var in elem_sch midd_sch high_sch elem_midd_sch midd_high_sch elmidhi_sch {
  replace `var' = 0 if `var' == .	
}
 
gl schools = "elem_sch midd_sch high_sch elem_midd_sch midd_high_sch elmidhi_sch"
 
* Visits by month
collapse (sum) school_visits, by(state month $schools)
gen year = 2019
order year month state school_visits
tempfile month_2019
save `month_2019', replace
 
// 2020-2021 mobility
use "$safeg/patterns_schoolsLong_2020.dta", clear
merge m:1 safegraph_place_id using `urban', keep(match using) nogen

gen month = month(date)
gen year = year(date)
drop if date == .
 
// Type of school
gen elem_sch = 1 if elem_cedp==1 & middle_cedp==0 & high_cedp==0
gen midd_sch = 1 if elem_cedp==0 & middle_cedp==1 & high_cedp==0
gen high_sch = 1 if elem_cedp==0 & middle_cedp==0 & high_cedp==1
gen elem_midd_sch = 1 if elem_cedp==1 & middle_cedp==1 & high_cedp==0
gen midd_high_sch = 1 if elem_cedp==0 & middle_cedp==1 & high_cedp==1
gen elmidhi_sch = 1 if elem_cedp==1 & middle_cedp==1 & high_cedp==1
 
foreach var in elem_sch midd_sch high_sch elem_midd_sch midd_high_sch elmidhi_sch {
  replace `var' = 0 if `var' == .	
}
 
gl schools = "elem_sch midd_sch high_sch elem_midd_sch midd_high_sch elmidhi_sch"
 
* Visits by month
collapse (sum) school_visits, by(state year month $schools)
order year month state school_visits
tempfile month_2020
save `month_2020', replace

*** Append 2019 and 2020 mobility datasets

use `month_2019', clear
append using `month_2020', force
save "$output/monthlySchool_mobility.dta", replace
